import { VersionInfo, Repositorys, State, ProgressInfo } from './types';
interface getVersionsProps {
    repositorys?: Repositorys[];
    count?: number;
}
/**
 * Fetch all available releases for given {@link Repositorys}.
 * If no repository is given, all {@link Repositorys} are checked.
 * @param repositorys array of {@link Repositorys}.
 * @defaultValue all {@link Repositorys}
 * @param count max versions to fetch for each {@link Repository}
 * @defaultValue 100
 * @returns * resolves with an array of {@link VersionInfo}
 *          * rejects with an {@link Error}
 */
declare function getAvailableVersions({ repositorys, count }: getVersionsProps): Promise<VersionInfo[]>;
interface installProps {
    versionInfo: VersionInfo;
    installDir: string;
    overwrite?: boolean;
    onProgress?: (state: State, progress?: ProgressInfo) => void;
    abortSignal?: AbortSignal;
}
/**
 * Installs a given version to the given installation directory.
 *
 * @param versionInfo the version to install as {@link VersionInfo}
 * @param installDir absolute path to installation directory
 * @param overwrite allow overwriting existing version installation
 * @defaultValue false
 * @param onProgress callback to get installation progress
 * @defaultValue void
 * @returns * resolves with updated {@link VersionInfo} and the full installation
 *            directory
 *          * rejects with an {@link Error}
 */
declare function installVersion({ versionInfo, installDir, overwrite, onProgress, abortSignal }: installProps): Promise<{
    versionInfo: VersionInfo;
    installDir: string;
}>;
export { getAvailableVersions, installVersion };
