import { ProgressInfo, State, VersionInfo, Type } from './types';
interface fetchProps {
    url: string;
    type: Type;
    count: number;
}
/**
 * Helper to fetch releases from given url.
 *
 * @param url url where to fetch releases from.
 * @param type type of the releases (wine, proton, ge, ...)
 * @param count number of releases to fetch
 * @returns * resolves with an array of {@link VersionInfo}
 *          * rejects with an {@link Error}
 */
declare function fetchReleases({ url, type, count }: fetchProps): Promise<VersionInfo[]>;
/**
 * Helper to unlink a file.
 *
 * @param filePath absolute path to file
 * @throws {@link Error}
 */
declare function unlinkFile(filePath: string): void;
/**
 * Helper to get disk space of installed version.
 *
 * @param folder absolute path to folder
 * @returns size of folder in bytes
 */
declare function getFolderSize(folder: string): number;
interface downloadProps {
    url: string;
    downloadDir: string;
    downsize: number;
    onProgress: (state: State, progress?: ProgressInfo) => void;
    abortSignal?: AbortSignal;
}
/**
 * Helper to download a file via curl.
 *
 * @param url url of the file
 * @param downloadDir absolute path to the download directory
 * @param downsize needed to calculate download speed
 * @param onProgress callback to get download progress
 * @param abortSignal signal to abort spawn
 * @returns resolves or rejects with a message
 */
declare function downloadFile({ url, downloadDir, downsize, onProgress, abortSignal }: downloadProps): Promise<string>;
interface unzipProps {
    filePath: string;
    unzipDir: string;
    overwrite?: boolean;
    onProgress: (state: State, progress?: ProgressInfo) => void;
    abortSignal?: AbortSignal;
}
/**
 * Helper to unzip an archive via tar.
 *
 * @param filePath url of the file
 * @param unzipDir absolute path to the unzip directory
 * @param overwrite allow overwriting existing unpacked files
 * @defaultValue false
 * @param onProgress callback to get unzip progress
 * @returns resolves or rejects with a message
 */
declare function unzipFile({ filePath, unzipDir, overwrite, onProgress, abortSignal }: unzipProps): Promise<string>;
export { fetchReleases, unlinkFile, getFolderSize, downloadFile, unzipFile };
